==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/RFQDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour RFQDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDBY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSEDUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSEOPT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQDETAILS_Type", propOrder = {
    "requestedby",
    "responsedue",
    "currencyid",
    "status",
    "responseopt"
})
public class RFQDETAILS_Type {

    @XmlElement(name = "REQUESTEDBY", required = true)
    protected PERSONID_Type requestedby;
    @XmlElement(name = "RESPONSEDUE", required = true)
    protected DATETIME responsedue;
    @XmlElement(name = "CURRENCYID", required = true)
    protected CURRENCYID_Type currencyid;
    @XmlElement(name = "STATUS", required = true)
    protected STATUS_Type status;
    @XmlElement(name = "RESPONSEOPT")
    protected String responseopt;

    /**
     * Obtient la valeur de la propriété requestedby.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getREQUESTEDBY() {
        return requestedby;
    }

    /**
     * Définit la valeur de la propriété requestedby.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setREQUESTEDBY(PERSONID_Type value) {
        this.requestedby = value;
    }

    /**
     * Obtient la valeur de la propriété responsedue.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getRESPONSEDUE() {
        return responsedue;
    }

    /**
     * Définit la valeur de la propriété responsedue.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setRESPONSEDUE(DATETIME value) {
        this.responsedue = value;
    }

    /**
     * Obtient la valeur de la propriété currencyid.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Définit la valeur de la propriété currencyid.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété responseopt.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESPONSEOPT() {
        return responseopt;
    }

    /**
     * Définit la valeur de la propriété responseopt.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESPONSEOPT(String value) {
        this.responseopt = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RFQDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for RFQDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDBY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSEDUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSEOPT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQDETAILS_Type", propOrder = {
    "requestedby",
    "responsedue",
    "currencyid",
    "status",
    "responseopt"
})
public class RFQDETAILS_Type {

    @XmlElement(name = "REQUESTEDBY", required = true)
    protected PERSONID_Type requestedby;
    @XmlElement(name = "RESPONSEDUE", required = true)
    protected DATETIME responsedue;
    @XmlElement(name = "CURRENCYID", required = true)
    protected CURRENCYID_Type currencyid;
    @XmlElement(name = "STATUS", required = true)
    protected STATUS_Type status;
    @XmlElement(name = "RESPONSEOPT")
    protected String responseopt;

    /**
     * Gets the value of the requestedby property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getREQUESTEDBY() {
        return requestedby;
    }

    /**
     * Sets the value of the requestedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setREQUESTEDBY(PERSONID_Type value) {
        this.requestedby = value;
    }

    /**
     * Gets the value of the responsedue property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getRESPONSEDUE() {
        return responsedue;
    }

    /**
     * Sets the value of the responsedue property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setRESPONSEDUE(DATETIME value) {
        this.responsedue = value;
    }

    /**
     * Gets the value of the currencyid property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Sets the value of the currencyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the responseopt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESPONSEOPT() {
        return responseopt;
    }

    /**
     * Sets the value of the responseopt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESPONSEOPT(String value) {
        this.responseopt = value;
    }

}
